@@ -14,7 +14,7 @@ import threading
 import time
 import unicodedata
 
-__version__ = '0.1.0'
+__version__ = '0.1.2'
 
 log = logging.getLogger(__name__)
 #log=logging
@@ -57,26 +57,24 @@ class EasyProcessCheckInstalledError(Exception):
                 msg += 'sudo apt-get install %s' % self.easy_process.ubuntu_package
         return msg
 
-
-class Proc():
+class EasyProcess():
     '''
+    .. module:: easyprocess
+    
     simple interface for :mod:`subprocess` 
 
     shell is not supported (shell=False)
     
+    :param cmd: string ('ls -l') or list of strings (['ls','-l']) 
+    :param max_bytes_to_log: logging of stdout and stderr is limited by this value
+    :param use_temp_files: use temp files instead of pipes for 
+                           stdout and stderr,
+                           pipes can cause deadlock in some cases
+                           (see unit tests)
     '''
     config = None
     
     def __init__(self, cmd, ubuntu_package=None, url=None, max_bytes_to_log=1000, cwd=None, use_temp_files=True):
-        '''
-        :param cmd: string ('ls -l') or list of strings (['ls','-l']) 
-        :param max_bytes_to_log: logging of stdout and stderr is limited 
-                                 by this value
-        :param use_temp_files: use temp files instead of pipes for 
-                               stdout and stderr,
-                               pipes can cause deadlock in some cases
-                               (see unit tests)
-        '''
         self.use_temp_files = use_temp_files
         self._outputs_processed = False
 
@@ -149,7 +147,7 @@ class Proc():
     @property
     def pid(self):
         '''
-        PID (subprocess.Popen.pid)
+        PID (:attr:`subprocess.Popen.pid`)
 
         :rtype: int
         '''
@@ -159,7 +157,7 @@ class Proc():
     @property
     def return_code(self):
         '''
-        returncode (``subprocess.Popen.returncode``)
+        returncode (:attr:`subprocess.Popen.returncode`)
 
         :rtype: int
         '''
@@ -212,6 +210,11 @@ class Proc():
         '''
         Run command with arguments. Wait for command to complete.
         
+        same as:
+         1. :meth:`start`
+         2. :meth:`wait`
+         3. :meth:`stop`
+        
         :rtype: self
         '''
         self.start().wait(timeout=timeout)
@@ -223,10 +226,6 @@ class Proc():
         '''
         start command in background and does not wait for it
         
-        Timeout:
-         - discussion: http://stackoverflow.com/questions/1191374/subprocess-with-timeout
-         - implementation: threading with polling
-        
         
         :rtype: self
         '''
@@ -274,7 +273,7 @@ class Proc():
 
     def is_alive(self):
         '''
-        poll process (:func:`subprocess.Popen.poll`)
+        poll process using :meth:`subprocess.Popen.poll`
         
         :rtype: bool
         '''
@@ -287,6 +286,10 @@ class Proc():
         '''
         Wait for command to complete.
         
+        Timeout:
+         - discussion: http://stackoverflow.com/questions/1191374/subprocess-with-timeout
+         - implementation: threading
+         
         :rtype: self
         '''
             
@@ -364,10 +367,12 @@ class Proc():
             
     def stop(self):
         '''
-        Kill process by sending SIGTERM.
+        Kill process
         and wait for command to complete.
         
-        same as ``sendstop().wait()``
+        same as:
+         1. :meth:`sendstop`
+         2. :meth:`wait`
         
         :rtype: self
         '''
@@ -375,7 +380,7 @@ class Proc():
 
     def sendstop(self):
         '''
-        Kill process by sending SIGTERM.
+        Kill process (:meth:`subprocess.Popen.terminate`).
         Do not wait for command to complete.
         
         :rtype: self
@@ -449,7 +454,7 @@ class Proc():
         self.stop()
 
 def extract_version(txt):
-    '''general method to get version from help text of any program
+    '''This function tries to extract the version from the help text of any program.
     '''
     words = txt.replace(',', ' ').split()
     version = None
@@ -463,4 +468,4 @@ def extract_version(txt):
     return version
 
 
-EasyProcess = Proc
+Proc = EasyProcess
