@@ -47,9 +47,7 @@ classifiers = [
     "Programming Language :: Python",
     ]
 
-install_requires = [
-    'setuptools',
-    ]
+install_requires = open("requirements.txt").read().split('\n')
 
 setup(
     name=NAME,
@@ -93,6 +91,7 @@ if ALL_TASKS_LOADED:
                                      ]
     
     options.paved.dist.manifest.include.remove('distribute_setup.py')
+    options.paved.dist.manifest.include.add('requirements.txt')
     
     
 #    @needs('sloccount', 'paver.doctools.html', 'pdf', 'sdist', 'nose')
